@@ -12,7 +12,7 @@ use Scalar::Util qw(blessed);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 sub new {
     my ( $class, %params ) = @_;
@@ -48,13 +48,16 @@ sub new {
             if ($adapter) {
                 $self->{'_inner_object'} = $adapter;
             } else {
+                warn 'Adapter not defined';
                 $self = undef;
             }
         } catch ($error) {
+            warn 'Unable to initialize adapter';
             $self = undef;
         }
 
     } elsif ( !$self->{'_inner_class'} ) {
+        warn 'No inner class instantiated';
         $self = undef;
     }
 
@@ -263,9 +266,11 @@ __END__
 
 =begin markdown
 
+# Date::Holidays
+
 [![CPAN version](https://badge.fury.io/pl/Date-Holidays.svg)](http://badge.fury.io/pl/Date-Holidays)
 [![Build Status](https://travis-ci.org/jonasbn/Date-Holidays.svg?branch=master)](https://travis-ci.org/jonasbn/Date-Holidays)
-[![Coverage Status](https://coveralls.io/repos/jonasbn/Date-Holidays/badge.png?branch=master)](https://coveralls.io/r/jonasbn/Date-Holidays?branch=master)
+[![Coverage Status](https://coveralls.io/repos/github/jonasbn/Date-Holidays/badge.svg?branch=master)](https://coveralls.io/github/jonasbn/Date-Holidays?branch=master)
 
 =end markdown
 
@@ -275,7 +280,7 @@ Date::Holidays - Date::Holidays::* adapter and aggregator for all your holiday n
 
 =head1 VERSION
 
-This POD describes version 1.05 of Date::Holidays
+This POD describes version 1.06 of Date::Holidays
 
 =head1 FEATURES
 
@@ -856,8 +861,10 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 =head1 LICENSE AND COPYRIGHT
 
 Date-Holidays and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2004-2015
+2004-2017
 
 Date-Holidays and related modules are released under the Artistic License 2.0
 
+Image used on L<website|https://jonasbn.github.io/Date-Holidays/> is under copyright by L<Markus Spiske|https://unsplash.com/@markusspiske?photo=AF_4tBQjdtc>
+
 =cut
